@@ -17,7 +17,6 @@ module Data.Acid.Local
     , openLocalStateFrom
     , prepareLocalState
     , prepareLocalStateFrom
-    , createLocalArchive
     , createCheckpointAndClose
     ) where
 
@@ -27,12 +26,12 @@ import Data.Acid.Common
 import Data.Acid.Abstract
 
 import Control.Concurrent             ( newEmptyMVar, putMVar, takeMVar, MVar )
-import Control.Exception              ( onException )
+import Control.Exception              ( onException, evaluate )
 import Control.Monad.State            ( runState )
 import Control.Monad                  ( join )
 import Control.Applicative            ( (<$>), (<*>) )
 import Data.ByteString.Lazy           ( ByteString )
---import qualified Data.ByteString.Lazy as Lazy ( length )
+import qualified Data.ByteString.Lazy as Lazy ( length )
 
 
 import Data.Serialize                 ( runPutLazy, runGetLazy )
@@ -81,8 +80,11 @@ scheduleLocalUpdate :: UpdateEvent event => LocalState (EventState event) -> eve
 scheduleLocalUpdate acidState event
     = do mvar <- newEmptyMVar
          let encoded = runPutLazy (safePut event)
-         --evaluate (Lazy.length encoded) -- It would be best to encode the event before we lock the core
-                                          -- but it hurts performance /-:
+
+         -- It is important that we encode the event now so that we can catch
+         -- any exceptions (see nestedStateError in examples/errors/Exceptions.hs)
+         evaluate (Lazy.length encoded)
+
          modifyCoreState_ (localCore acidState) $ \st ->
            do let !(result, !st') = runState hotMethod st
               -- Schedule the log entry. Very important that it happens when 'localCore' is locked
@@ -280,13 +282,6 @@ closeLocalState acidState
          closeFileLog (localCheckpoints acidState)
          releasePrefixLock (localLock acidState)
 
-
--- | Move all log files that are no longer necessary for state restoration into the 'Archive'
---   folder in the state directory. This folder can then be backed up or thrown out as you see fit.
---   Reverting to a state before the last checkpoint will not be possible if the 'Archive' folder
---   has been thrown out.
---
---   This method is idempotent and does not block the normal operation of the AcidState.
 createLocalArchive :: LocalState st -> IO ()
 createLocalArchive state
   = do -- We need to look at the last checkpoint saved to disk. Since checkpoints can be written
